import React from "react";
import {
  PRE_GAME,
  PRE_ROUND,
  IN_ROUND,
  POST_ROUND,
  POST_GAME,
  ERROR,
} from "./game-state.enum";
import PreGameContainer from '../pre-game.component';
import PreRound from '../pre-round.component';
import GamePanelContainer from "../game-panel.component";
import RoundSummary from '../round-summary.component';
import PlayerScoresContainer from "../player-scores.component";

class Game extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      gameState: PRE_GAME,
      gameId: null,
      playerName: null,
      lastRound: null,
    }
  }

  render() {
    const { gameState, gameId, playerName, lastRound } = this.state;
    
    switch (gameState) {
      case PRE_GAME:
        return <PreGameContainer 
          onGameJoined={({ gameId, playerName }) => this.setState({ gameState: PRE_ROUND, gameId, playerName })}
        />
      case PRE_ROUND:
        return <PreRound
          gameId={gameId}
          playerName={playerName}
          onStart={() => this.setState({ gameState: IN_ROUND })}
        />
      case IN_ROUND:
        return <GamePanelContainer
          gameId={gameId}
          playerName={playerName}
          onRoundEnd={lastRound => this.setState({ gameState: POST_ROUND, lastRound })}
          onGameEnd={() => this.setState({ gameState: POST_GAME })}
        />
      case POST_ROUND:
        return <RoundSummary
          round={lastRound}
          onNext={() => this.setState({ gameState: IN_ROUND })}
        />
      case POST_GAME:
        return <PlayerScoresContainer
          gameId={gameId}
          onReturnToStart={() => this.setState({ gameState: PRE_GAME })}
        />
      case ERROR:
        // TODO - would be nice to hook this into the sub-components, maybe with a HOC?
        return <p>Application encountered unrecoverable error, please refresh the page.</p>
      default:
        this.setState({ gameState: ERROR });
        return <p>Application state is inconsistent, please refresh and rejoin your previous game.</p>
    }
  }
}

export default Game;
