import React from "react";
import Loading from "./loading.component";
import { createGame, joinGame } from "../services/ggsh.service";

// TODO set round timer for new game

const PreGame = ({
  onCreateGame,
  onJoinGame,
  onChangeGameId,
  onChangePlayerName,
  gameId,
  playerName
}) => (
  <div>
    <p>Player Name</p>
    <input type="text" value={playerName} onChange={onChangePlayerName} />
    <hr/>
    <button 
      onClick={onCreateGame}
      disabled={!playerName || playerName.length === 0}
    >
      Create New Game
    </button>
    <hr/>
    
    <p>Game ID:</p>
    <input type="text" value={gameId} onChange={onChangeGameId} />
    <br/>
    <button 
      onClick={onJoinGame}
      disabled={!gameId || !playerName || gameId.length === 0 || playerName.length === 0}
    >
      Join Existing Game
    </button>
  </div>
);

class PreGameContainer extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      loading: false,
      gameId: null,
      playerName: null,
    }
  }

  async handleCreateGame() {
    this.setState({ loading: true });
    const { playerName } = this.state;
    const gameId = await createGame(playerName, 300);
    const { onGameJoined } = this.props;
    onGameJoined({ gameId, playerName });
  }
  
  async handleJoinGame() {
    // TODO would like to support re-joining a game you left
    this.setState({ loading: true });
    const { gameId, playerName } = this.state;
    await joinGame(gameId, playerName);
    const { onGameJoined } = this.props;
    onGameJoined({ gameId, playerName });
  }

  render() {
    const { loading, gameId, playerName } = this.state;
    if (loading) {
      return <Loading/>
    }

    return <PreGame
      onCreateGame={() => this.handleCreateGame()}
      onJoinGame={() => this.handleJoinGame()}
      onChangeGameId={({ target }) => this.setState({gameId: target.value.trim()})}
      onChangePlayerName={({ target }) => this.setState({playerName: target.value.trim()})}
      gameId={gameId || ""}
      playerName={playerName || ""}
    />
  }
}

export default PreGameContainer;
